@@ -7,6 +7,7 @@ from pandas.api.types import is_datetime64_any_dtype as is_datetime
 
 
 from cgdb.exceptions.ColumnNotFound import ColumnNotFoundException
+from cgdb.resources import OverwriteStrategy
 from cgdb.resources.dataSet import DataSets
 from cgdb.utils.ManagerMix import ManagerMix
 
@@ -110,7 +111,7 @@ class DataSetsManager(ManagerMix):
     #
     #     return pd.DataFrame(columns)
 
-    def post_data_set_data2(self, data: pd.DataFrame, data_set: DataSets):
+    def post_data_set_data2(self, data: pd.DataFrame, data_set: DataSets, overwriteStrategy: str = None):
         print(data)
 
         if "date_time" not in data.columns:
@@ -177,6 +178,12 @@ class DataSetsManager(ManagerMix):
 
         out = json.dumps(out)
 
+
+        url = data_set.url + "/data"
+
+        if overwriteStrategy is not None:
+            url += "?overwriteStrategy=" + overwriteStrategy
+
         a = self._client._session.post(data_set.url+"/data", data=out)
         if a.status_code != 200:
             raise Exception("upload fail on server side "+a.text)
